@@ -1,9 +1,9 @@
 package Data::Sah::Filter::js::Str::downcase;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-02-11'; # DATE
+our $DATE = '2020-05-31'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,7 +44,7 @@ Data::Sah::Filter::js::Str::downcase - Convert string to lowercase
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::Filter::js::Str::downcase (from Perl distribution Data-Sah-Filter), released on 2020-02-11.
+This document describes version 0.006 of Data::Sah::Filter::js::Str::downcase (from Perl distribution Data-Sah-Filter), released on 2020-05-31.
 
 =head1 SYNOPSIS
 
@@ -70,6 +70,13 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+Related filters: L<upcase|Data::Sah::Filter::js::Str::upcase>.
+
+Synonym: L<lc|Data::Sah::Filter::js::Str::lc>,
+L<lowercase|Data::Sah::Filter::js::Str::lowercase>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
